==> beast-0.5.0-rc1.tar.gz: beast-0.5.0-rc1/beast-gtk/bstgentypes.c <==

/* Generated data (by glib-mkenums) */


GType bst__type_id__BstMarkerType = 0;

GType bst__type_id__BstChoiceFlags = 0;

GType bst__type_id__BstQSamplerType = 0;

GType bst__type_id__BstQSamplerDrawMode = 0;

GType bst__type_id__BstRadioToolsFlags = 0;

GType bst__type_id__BstOps = 0;

GType bst__type_id__BstQuantizationType = 0;

/* Generated data ends here */


/*-------- begin ../sfi/sfidl generated code --------*/


BstGConfig*
bst_gconfig_new (void)
{
  BstGConfig* rec = g_new0 (BstGConfig, 1);
  return rec;
}

BstGConfig*
bst_gconfig_copy_shallow (BstGConfig* rec)
{
  BstGConfig* rec_copy = NULL;

  g_return_val_if_fail (rec != NULL, NULL);
  rec_copy = bst_gconfig_new ();
  rec_copy->rc_version = g_strdup (rec->rc_version);
  rec_copy->snet_anti_aliased = rec->snet_anti_aliased;
  rec_copy->snet_edit_fallback = rec->snet_edit_fallback;
  rec_copy->snet_swap_io_channels = rec->snet_swap_io_channels;
  rec_copy->tab_width = rec->tab_width;
  return rec_copy;
}

BstGConfig*
bst_gconfig_from_rec (SfiRec *sfi_rec)
{
  GValue *element;
  BstGConfig* rec;

  g_return_val_if_fail (sfi_rec != NULL, NULL);

  rec = g_new0 (BstGConfig, 1);
  element = sfi_rec_get (sfi_rec, "rc_version");
  if (element)
    rec->rc_version = g_strdup (sfi_value_get_string (element));
  element = sfi_rec_get (sfi_rec, "snet_anti_aliased");
  if (element)
    rec->snet_anti_aliased = sfi_value_get_bool (element);
  element = sfi_rec_get (sfi_rec, "snet_edit_fallback");
  if (element)
    rec->snet_edit_fallback = sfi_value_get_bool (element);
  element = sfi_rec_get (sfi_rec, "snet_swap_io_channels");
  if (element)
    rec->snet_swap_io_channels = sfi_value_get_bool (element);
  element = sfi_rec_get (sfi_rec, "tab_width");
  if (element)
    rec->tab_width = sfi_value_get_int (element);
  return rec;
}

SfiRec *
bst_gconfig_to_rec (BstGConfig* rec)
{
  SfiRec *sfi_rec;
  GValue *element;

  g_return_val_if_fail (rec != NULL, NULL);

  sfi_rec = sfi_rec_new ();
  element = sfi_value_string (rec->rc_version);
  sfi_rec_set (sfi_rec, "rc_version", element);
  sfi_value_free (element);
  element = sfi_value_bool (rec->snet_anti_aliased);
  sfi_rec_set (sfi_rec, "snet_anti_aliased", element);
  sfi_value_free (element);
  element = sfi_value_bool (rec->snet_edit_fallback);
  sfi_rec_set (sfi_rec, "snet_edit_fallback", element);
  sfi_value_free (element);
  element = sfi_value_bool (rec->snet_swap_io_channels);
  sfi_rec_set (sfi_rec, "snet_swap_io_channels", element);
  sfi_value_free (element);
  element = sfi_value_int (rec->tab_width);
  sfi_rec_set (sfi_rec, "tab_width", element);
  sfi_value_free (element);
  return sfi_rec;
}

void
bst_gconfig_free (BstGConfig* rec)
{
  g_return_if_fail (rec != NULL);
  
  g_free (rec->rc_version);
  g_free (rec);
}


static GParamSpec *bst_gconfig_field[5];
SfiRecFields bst_gconfig_fields = { 5, bst_gconfig_field };

static void
_bst_init_idl (void)
{
  bst_gconfig_field[0] = sfidl_pspec_String (NULL,"rc_version",NULL , "Release counter" , NULL , SFI_PARAM_STORAGE);
  bst_gconfig_field[1] = sfidl_pspec_Bool ("Synthesis","snet_anti_aliased","Anti-Alias" , "Draw synthesis networks anti-aliased?" , TRUE , SFI_PARAM_DEFAULT);
  bst_gconfig_field[2] = sfidl_pspec_Bool ("Synthesis","snet_edit_fallback","Single Edit" , "Fallback into Edit mode after creating synthesis modules?" , TRUE , SFI_PARAM_DEFAULT);
  bst_gconfig_field[3] = sfidl_pspec_Bool ("Synthesis","snet_swap_io_channels","Swap IO" , "Swap input with output channels when displaying synthesis modules?" , FALSE , SFI_PARAM_DEFAULT);
  bst_gconfig_field[4] = sfidl_pspec_Int ("Misc","tab_width","Tab Width" , "Specify project tab width in pixels" , 0 , 0 , 5000 , 5 , SFI_PARAM_DEFAULT);
}


/*-------- end ../sfi/sfidl generated code --------*/

==> beast-0.5.1.tar.gz: beast-0.5.1/beast-gtk/bstgentypes.c <==

/* Generated data (by glib-mkenums) */


GType bst__type_id__BstMarkerType = 0;

GType bst__type_id__BstChoiceFlags = 0;

GType bst__type_id__BstQSamplerType = 0;

GType bst__type_id__BstQSamplerDrawMode = 0;

GType bst__type_id__BstRadioToolsFlags = 0;

GType bst__type_id__BstOps = 0;

GType bst__type_id__BstQuantizationType = 0;

/* Generated data ends here */


/*-------- begin ../sfi/sfidl generated code --------*/


BstGConfig*
bst_gconfig_new (void)
{
  BstGConfig* rec = g_new0 (BstGConfig, 1);
  return rec;
}

BstGConfig*
bst_gconfig_copy_shallow (BstGConfig* rec)
{
  BstGConfig* rec_copy = NULL;

  g_return_val_if_fail (rec != NULL, NULL);
  rec_copy = bst_gconfig_new ();
  rec_copy->rc_version = g_strdup (rec->rc_version);
  rec_copy->snet_anti_aliased = rec->snet_anti_aliased;
  rec_copy->snet_edit_fallback = rec->snet_edit_fallback;
  rec_copy->snet_swap_io_channels = rec->snet_swap_io_channels;
  rec_copy->tab_width = rec->tab_width;
  return rec_copy;
}

BstGConfig*
bst_gconfig_from_rec (SfiRec *sfi_rec)
{
  GValue *element;
  BstGConfig* rec;

  g_return_val_if_fail (sfi_rec != NULL, NULL);

  rec = g_new0 (BstGConfig, 1);
  element = sfi_rec_get (sfi_rec, "rc_version");
  if (element)
    rec->rc_version = g_strdup (sfi_value_get_string (element));
  element = sfi_rec_get (sfi_rec, "snet_anti_aliased");
  if (element)
    rec->snet_anti_aliased = sfi_value_get_bool (element);
  element = sfi_rec_get (sfi_rec, "snet_edit_fallback");
  if (element)
    rec->snet_edit_fallback = sfi_value_get_bool (element);
  element = sfi_rec_get (sfi_rec, "snet_swap_io_channels");
  if (element)
    rec->snet_swap_io_channels = sfi_value_get_bool (element);
  element = sfi_rec_get (sfi_rec, "tab_width");
  if (element)
    rec->tab_width = sfi_value_get_int (element);
  return rec;
}

SfiRec *
bst_gconfig_to_rec (BstGConfig* rec)
{
  SfiRec *sfi_rec;
  GValue *element;

  g_return_val_if_fail (rec != NULL, NULL);

  sfi_rec = sfi_rec_new ();
  element = sfi_value_string (rec->rc_version);
  sfi_rec_set (sfi_rec, "rc_version", element);
  sfi_value_free (element);
  element = sfi_value_bool (rec->snet_anti_aliased);
  sfi_rec_set (sfi_rec, "snet_anti_aliased", element);
  sfi_value_free (element);
  element = sfi_value_bool (rec->snet_edit_fallback);
  sfi_rec_set (sfi_rec, "snet_edit_fallback", element);
  sfi_value_free (element);
  element = sfi_value_bool (rec->snet_swap_io_channels);
  sfi_rec_set (sfi_rec, "snet_swap_io_channels", element);
  sfi_value_free (element);
  element = sfi_value_int (rec->tab_width);
  sfi_rec_set (sfi_rec, "tab_width", element);
  sfi_value_free (element);
  return sfi_rec;
}

void
bst_gconfig_free (BstGConfig* rec)
{
  g_return_if_fail (rec != NULL);
  
  g_free (rec->rc_version);
  g_free (rec);
}


static GParamSpec *bst_gconfig_field[5];
SfiRecFields bst_gconfig_fields = { 5, bst_gconfig_field };

static void
_bst_init_idl (void)
{
  bst_gconfig_field[0] = sfidl_pspec_String (NULL,"rc_version",NULL , "Release counter" , NULL , SFI_PARAM_STORAGE);
  bst_gconfig_field[1] = sfidl_pspec_Bool ("Synthesis Networks","snet_anti_aliased","Anti-Alias" , "Draw synthesis networks anti-aliased?" , TRUE , SFI_PARAM_DEFAULT);
  bst_gconfig_field[2] = sfidl_pspec_Bool ("Synthesis Networks","snet_edit_fallback","Single Edit" , "Fallback into Edit mode after creating synthesis modules?" , TRUE , SFI_PARAM_DEFAULT);
  bst_gconfig_field[3] = sfidl_pspec_Bool ("Synthesis Networks","snet_swap_io_channels","Swap IO" , "Swap input with output channels when displaying synthesis modules?" , FALSE , SFI_PARAM_DEFAULT);
  bst_gconfig_field[4] = sfidl_pspec_Int ("Misc","tab_width","Tab Width" , "Specify project tab width in pixels" , 0 , 0 , 5000 , 5 , SFI_PARAM_DEFAULT);
}


/*-------- end ../sfi/sfidl generated code --------*/
